Module: Sevgi::Graphics::Mixtures::Polyfills

Defined in:
lib/sevgi/graphics/mixtures/polyfills.rb

Overview

Compatibility helpers for profiles that do not load richer mixtures.

Instance Method Summary collapse

Instance Method Details

#layer(*args, **attributes) ⇒ Sevgi::Graphics::Element

Builds a generic group as a layer fallback.

Parameters:

  • args (Array<Object>)

    group content arguments

  • attributes (Hash)

    group attributes

Returns:



13
# File 'lib/sevgi/graphics/mixtures/polyfills.rb', line 13

def layer(...) = g(...)

#symbol!(*args, **attributes) ⇒ Sevgi::Graphics::Element

Builds a regular symbol as a fallback for hidden symbols.

Parameters:

  • args (Array<Object>)

    symbol content arguments

  • attributes (Hash)

    symbol attributes

Returns:



20
# File 'lib/sevgi/graphics/mixtures/polyfills.rb', line 20

def symbol!(...) = symbol(...)