Module: Sevgi::Graphics::Mixtures::Polyfills
- Defined in:
- lib/sevgi/graphics/mixtures/polyfills.rb
Overview
Compatibility helpers for profiles that do not load richer mixtures.
Instance Method Summary collapse
-
#layer(*args, **attributes) ⇒ Sevgi::Graphics::Element
Builds a generic group as a layer fallback.
-
#symbol!(*args, **attributes) ⇒ Sevgi::Graphics::Element
Builds a regular symbol as a fallback for hidden symbols.
Instance Method Details
#layer(*args, **attributes) ⇒ Sevgi::Graphics::Element
13 |
# File 'lib/sevgi/graphics/mixtures/polyfills.rb', line 13 def layer(...) = g(...) |
#symbol!(*args, **attributes) ⇒ Sevgi::Graphics::Element
20 |
# File 'lib/sevgi/graphics/mixtures/polyfills.rb', line 20 def symbol!(...) = symbol(...) |